package HTE::CmdTree;

require 5.005_62;
use strict;
use warnings;

our $VERSION = '0.90';

=head1 NAME

HTE::CmdTree - Command Syntax manager the Host Table Editor program

=head1 DESCRIPTION

=cut

sub new {

  my $class = shift;

  my $self  = {};

  $self->{_name  } = 'hte';
  $self->{_parent} = '';

  bless $self;

}

sub node {

  my $self   = shift;
  my $node   = shift;
  my $create = shift;

  return $self if ($node eq $self->{_name});

  my $key;
  my $base = ( $self->{_parent} ) ? 
    join(' ',$self->{_parent},$self->{_name}) : $self->{_name};

  my $nh   = $self;
  my @bits = split(/\s+/,$node);

  shift @bits if ( $self->name eq $bits[0]);

  if ($create) {
    for $key (@bits) {
      $nh->{$key}->{_name}   = $key;
      $nh->{$key}->{_parent} = $base;
      $nh = $nh->{$key};
      $base .= " $key";
    }
  }

  $nh = $self;
  for $key (@bits) {
    if ( exists $nh->{$key} ) {
      $nh = $nh->{$key};
    } else {
      return;
    }
  }

  bless $nh;

}

sub desc   { $_[0]->param('_desc',$_[1]) }
sub cmd    { $_[0]->param('_cmd', $_[1]) }
sub name   { $_[0]->param('_name'  ) }     # Read Only
sub parent { $_[0]->param('_parent') }     # Read Only

sub param {

  my $self  = shift;
  my $param = shift;
  my $value = shift;

  $self->{$param} = $value if ($value);
  return $self->{$param};

}

sub list {

  my $self = shift;
  return grep(!/^_/,keys(%$self));

}

=head1 AUTHOR

Daniel Speers (dan@speers.nu)

=head1 SEE ALSO

HTE(1) - The Host table editor program

=cut

1;
__END__
